{% load static %}

<div class="row">
    <div class="col-md-8">

        <div class="myuw-card myuw-card-article">
            <h3 class="myuw-card-title">The Long View</h3>
            <p class="myuw-card-tagline">Weekly thoughts on making the most of your Husky Experience</p>

            <div class="myuw-article-teaser-wrapper">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/tired_feeling_alone_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/tired_feeling_alone_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/tired_feeling_alone_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/tired_feeling_alone_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 480vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/tired_feeling_alone_650.jpg' %}"
                         alt="A crowd of students walking to classes on Red Square.">
                

                
                    <p>Dennis Wise</p>
                

                <div class="myuw-article-teaser">
                    <h4><span class="myuw-highlight">Tired of Feeling Alone?</span></h4>
                    <p><span class="myuw-highlight">UW is huge. How do you find friends you really click with?<a href="/husky_experience?article=tired-feeling-alone">Here is the link to the article.</a></span></p>
                </div>
            </div>
        </div>

    </div>
    <div class="col-md-4">

    </div>
</div>