{% load static %}

<div class="myuw-article">
    <div class="row">
        <div class="col-md-8">
            <div class="myuw-article-meta">
                <a href="/husky_experience/">Husky Experience</a>: Thrive - Know the World
            </div>
            <h2 class="myuw-heading-page">Solve World Problems</h2>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">

            <figure class="myuw-article-heroimage">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/solve_world_problems_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/solve_world_problems_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/solve_world_problems_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/solve_world_problems_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 100vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/solve_world_problems_650.jpg' %}"
                         alt="Students and faculties on a boat in Puget Sound studying various fish.">
                
                
            </figure>

            <p>First, know that your contributions will be welcome, however large or small, and many paths are available to you to make a difference in the world. Most problems facing humanity are extremely complex, and their solutions require thousands of contributors from many disciplines with diverse skill sets.</p>

<p>If you're set on tackling world issues, you might start by identifying the ways you like to tackle and solve problems generally. Do you like being "up close and personal" with a problem&#8211;on the ground administering vaccines, for example&#8211;or do you prefer to address "the big picture" &#8211;maybe monitoring the path of an epidemic? The next step is to identify which disciplines (and majors) best align to the way in which you like tackling and solving problems. One way to do this is by searching UW.edu or UW Today for news about faculty or organizations working on the issues you care about. Find the people mentioned, and make an appointment to talk to them. Try to get a sense of the following:</p>
<ul>
<li>How are they approaching the problem?</li>
<li>What types of questions are they asking?</li> 
<li>What tools and methods are they bringing to bear on the problem?</li> 
<li>What knowledge and skills do they anticipate will be needed to effectively address this problem in the future?</li>
</ul>
<p>Another approach is to <a href="myplan.uw.edu" target="_blank">search for courses</a> with key words related to the issue you care about. Talk to a librarian to learn more about the perspectives different disciplines bring to bear on this issue. Know of a major that might be of interest? Find someone in that major and talk to them about it to learn what approaches to problems are used in that discipline.</p>

<p>Finally, recognize that you may get to create your own career path through a combination of courses and majors; it's rare to find a major that exactly matches a career. Remember the world is constantly changing, and the job you end up doing may not exist yet!</p>

            

            
                <h3 class="myuw-heading-page">Related Topic</h3>
                <ul>
                    
                        <li><a href="/husky_experience?article=wheres-your-focuslearning-or-competing">Where&#39;s Your Focus–Learning or Competing?</a></li>
                    
                        <li><a href="/husky_experience?article=falling-love-class">Falling in Love with a Class</a></li>
                    
                        <li><a href="/husky_experience?article=do-majors-jobs">Do Majors = Jobs?</a></li>
                    
                        <li><a href="/husky_experience?article=got-experience">Got Experience?</a></li>
                    
                        <li><a href="/husky_experience?article=what-if-grade-didnt-matter">What If the Grade Didn&#39;t Matter?</a></li>
                    
                </ul>
            

        </div>

        <div class="col-md-4">
            <div class="myuw-canvas myuw-article-aside">
                <h3 class="myuw-canvas-title">About Thrive Messages</h3>
                <p>Thrive messages are designed to help UW students succeed wherever they are in their University career. The message address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Make Sense.
                </p>
                <a href="#">Learn more about Thrive and the Husky Experience.</a>
            </div>
        </div>
    </div>

</div>
