# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-12-19 19:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hx_toolkit', '0003_auto_20171215_0313'),
    ]

    operations = [
        migrations.AddField(
            model_name='article',
            name='image_credit',
            field=models.TextField(blank=True, null=True),
        ),
    ]
