{% load static %}

<div class="myuw-article">
    <div class="row">
        <div class="col-md-8">
            <div class="myuw-article-meta">
                <a href="/husky_experience/">Husky Experience</a>: Thrive - Know the World
            </div>
            <h2 class="myuw-heading-page">Got Experience?</h2>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">

            <figure class="myuw-article-heroimage">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/got_experience_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/got_experience_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/got_experience_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/got_experience_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 100vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/got_experience_650.jpg' %}"
                         alt="Jeff Bradley and a team from the Burke Museum excavate a Baird&#39;s Beaked Whale at Grayland Beach State Park in Washington State.">
                
                
            </figure>

            <p>No matter where you are in your undergraduate career, you can always branch out and get experiences that will augment your classroom learning.</p>

<p>Internships – an opportunity to learn while working – are one way. The Career and Internship Center has resources for all stages, from helping students search and find internships to assistance in making sense of their experience. The Career and Internship Center talked to students who shared <a href="https://youtu.be/oCz3pR5j8p0">their internship advice</a>.</p>

<p>Experience can also be found through other outside-the-classroom learning experiences like <a href="http://www.washington.edu/undergradresearch/">undergraduate research</a> and <a href="http://www.washington.edu/carlson/students-3/browse-service-learning-positions/">service-learning</a> or <a href="http://www.washington.edu/carlson/service-opportunities/">volunteering</a>. This is not just about working in a lab or volunteering at a food bank – there are literally hundreds of different ways to contribute. You might be surprised by what you find. </p>

<p>Doing something new and making connections with others can be scary. Remember that stepping out of your comfort zone can feel awkward and uncertain, but can result in rich rewards.</p>

            

            
                <h3 class="myuw-heading-page">Related Topic</h3>
                <ul>
                    
                        <li><a href="/husky_experience?article=solve-world-problems">Solve World Problems</a></li>
                    
                        <li><a href="/husky_experience?article=do-majors-jobs">Do Majors = Jobs?</a></li>
                    
                        <li><a href="/husky_experience?article=does-your-resume-represent-you">Does Your Résumé Represent You?</a></li>
                    
                        <li><a href="/husky_experience?article=plan-your-life-accident">Plan Your Life by Accident</a></li>
                    
                </ul>
            

        </div>

        <div class="col-md-4">
            <div class="myuw-canvas myuw-article-aside">
                <h3 class="myuw-canvas-title">About Thrive Messages</h3>
                <p>Thrive messages are designed to help UW students succeed wherever they are in their University career. The message address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Make Sense.
                </p>
                <a href="#">Learn more about Thrive and the Husky Experience.</a>
            </div>
        </div>
    </div>

</div>
