{% load static %}

<div class="myuw-article">
    <div class="row">
        <div class="col-md-8">
            <div class="myuw-article-meta">
                <a href="/husky_experience/">Husky Experience</a>: Thrive - Know Yourself
            </div>
            <h2 class="myuw-heading-page">Bouncing Back</h2>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">

            <figure class="myuw-article-heroimage">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/bouncing_back_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/bouncing_back_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/bouncing_back_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/bouncing_back_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 100vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/bouncing_back_650.jpg' %}"
                         alt="Roses from the rose garden surrounding Drumheller Fountain.">
                
                
                    <p>Katherine B. Turner</p>
                
            </figure>

            <p>You may have heard about a “fixed” vs. “growth” mindset. A mindset, or pattern of beliefs, can affect thoughts and behaviors positively or negatively.</p>

<p>In a “fixed mindset,” people believe that things like intelligence, character, and creative abilities are fixed traits. They may have been praised for their abilities when they were younger and may feel like they don’t need to put in a lot of effort because their achievements have always “just come naturally.” When people with a fixed mindset encounter a genuine challenge, they begin to doubt their abilities and avoid taking risks in the future, for fear of looking like a failure or having their deficiencies exposed. They’re also not very good at hearing critical feedback, because what they hear is that someone is disappointed in them, not that there are ways that they can improve their work, or their relationships.</p>

<p>In contrast, people with a “growth mindset” believe that qualities like intelligence, creativity, and even the capacity for positive relationships, can be developed through effort and practice. They are not defined by their failures, but see them as an opportunity to try harder next time. When they encounter a challenge, they’re motivated to find a solution and may encourage themselves with the thought, “I don’t have the answer&#8230;yet.” In addition, people with a growth mindset welcome critical feedback, because they know it will tell them where they need to place their effort in order to succeed, in their work or relationships.</p>

<p>You may have a “fixed” or “growth” mindset at different times in your life, or in different areas of your life. It’s worth learning more about these mindsets, as well as strategies for altering “fixed” beliefs. A “growth mindset” will help you improve your attitude toward failure, your comfort taking risks, and your chances for success. Practice it now, and it will serve you well into the future.</p>

            
                <h3 class="myuw-heading-page">Resources</h3>
                <ul>
                    
                        <li><a href="https://www.youtube.com/watch?v=KUWn_TJTrnU">Growth Mindset vs. Fixed Mindset</a></li>
                    
                        <li><a href="https://www.youtube.com/watch?v=aNHas97iE78">4 Steps to a Developing a Growth Mindset</a></li>
                    
                </ul>
            

            
                <h3 class="myuw-heading-page">Related Topic</h3>
                <ul>
                    
                        <li><a href="/husky_experience?article=no-time-be-healthy">No Time to be Healthy?</a></li>
                    
                        <li><a href="/husky_experience?article=are-you-your-gpa">Are you your GPA?</a></li>
                    
                </ul>
            

        </div>

        <div class="col-md-4">
            <div class="myuw-canvas myuw-article-aside">
                <h3 class="myuw-canvas-title">About Thrive Messages</h3>
                <p>Thrive messages are designed to help UW students succeed wherever they are in their University career. The message address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Make Sense.
                </p>
                <a href="#">Learn more about Thrive and the Husky Experience.</a>
            </div>
        </div>
    </div>

</div>
