{% load static %}

<div class="myuw-article">
    <div class="row">
        <div class="col-md-8">
            <div class="myuw-article-meta">
                <a href="/husky_experience/">Husky Experience</a>: Thrive - Know the World
            </div>
            <h2 class="myuw-heading-page">Where&#39;s Your Focus–Learning or Competing?</h2>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">

            <figure class="myuw-article-heroimage">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/whats_your_focus_learning_competing_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/whats_your_focus_learning_competing_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/whats_your_focus_learning_competing_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/whats_your_focus_learning_competing_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 100vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/whats_your_focus_learning_competing_650.jpg' %}"
                         alt="">
                
                
                    <p>College of Arts &amp; Sciences</p>
                
            </figure>

            <p>You faced competition getting into UW, and you may still be feeling competition now that you're in. Some academic pressure can be motivating, but competition can be harmful when you find yourself always comparing yourself to others, obsessing about grades, or feeling jealous or bitter about others’ accomplishments. Competition may exist, but you don’t have to suffer because of it. Here are some options for dealing with it:</p>
<ul>
<li><strong>Acknowledge your frustrations and disappointments</strong><br />
When you are feeling the burden of competition, give your feelings a voice. Take a moment and try to articulate what you’re feeling in a specific statement like “I’m frustrated that I spend so much time studying but still don’t get the highest grades” or “I’m disappointed that I didn’t get that internship.” Acknowledging your feelings can lessen their impact.</li>

<li><strong>Expect to "win some, lose some"</strong><br />
No matter how much effort you put in, you can’t expect to always come out on top. Dealing with competition means developing a healthy attitude toward both winning and losing. Be proud when you’re successful, and don’t beat yourself up if you don’t always excel. 

<li><strong>Focus on yourself and your own goals</strong><br />
The “everyone else is better than me” mindset disappears when you don’t focus on everyone else. Focus on the goals YOU set for yourself. Be clear about what you want to achieve and work steadily toward it. Acknowledge how much you’re learning, and be proud of the effort you put in AND how you’re taking care of yourself. Other people’s performance doesn’t matter. Really.</li>

<li><strong>Cultivate a non-competitive environment</strong><br />
If you wish the environment in your program were less competitive, then make a change to be kinder. Offer help to others–they may be willing to reciprocate in the future. When someone announces an achievement, offer a sincere congratulations, and then change the subject. Let your work and your actions speak for themselves.</li>

<li><strong>Recognize that admission into a competitive program is not admission into an elite program</strong><br />
UW has several capacity-constrained majors, and it’s true that not everyone who applies to one of these majors can be accepted. Recognize that those accepted are not better people than those who were not accepted. Don’t tie your self-worth to an institutional constraint.</li>

<li><strong>See happiness as a greater accomplishment</strong><br />
Finally, recognize that your happiness and overall mental health are more important than grades and school. Invest in friendships. Take time to play and relax. Super competitive students are usually not happy. Focus on the happiness you can gain from where you are.</li>
</ul>

            

            
                <h3 class="myuw-heading-page">Related Topic</h3>
                <ul>
                    
                        <li><a href="/husky_experience?article=solve-world-problems">Solve World Problems</a></li>
                    
                        <li><a href="/husky_experience?article=do-majors-jobs">Do Majors = Jobs?</a></li>
                    
                        <li><a href="/husky_experience?article=are-you-your-gpa">Are you your GPA?</a></li>
                    
                        <li><a href="/husky_experience?article=what-if-grade-didnt-matter">What If the Grade Didn&#39;t Matter?</a></li>
                    
                </ul>
            

        </div>

        <div class="col-md-4">
            <div class="myuw-canvas myuw-article-aside">
                <h3 class="myuw-canvas-title">About Thrive Messages</h3>
                <p>Thrive messages are designed to help UW students succeed wherever they are in their University career. The message address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Make Sense.
                </p>
                <a href="#">Learn more about Thrive and the Husky Experience.</a>
            </div>
        </div>
    </div>

</div>
