{% load static %}

<div class="myuw-article">
    <div class="row">
        <div class="col-md-8">
            <div class="myuw-article-meta">
                <a href="/husky_experience/">Husky Experience</a>: Thrive - Know Yourself
            </div>
            <h2 class="myuw-heading-page">Your Friends, Your Success</h2>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">

            <figure class="myuw-article-heroimage">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/your_friends_your_success_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/your_friends_your_success_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/your_friends_your_success_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/your_friends_your_success_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 100vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/your_friends_your_success_650.jpg' %}"
                         alt="Environmental Science North Cascades Group Field Trip.">
                
                
            </figure>

            <p>There’s no one right way to “do” friends at UW – some people have many friends from different social circles, others have a few close ties. What’s important is the quality of those relationships. Research shows that friendships support your success when they provide the following:</p>

<h3>Social support</h3>
<p>All work and no play is not the way to succeed. Seek friends who can share with you your ups and downs, make you laugh, and get you out and doing things. </p>

<h3>Academic help</h3>
<p>Seek friends who can advise you on study strategies, recommend courses, or introduce you to new majors. Study buddies also matter – people who to proofread your drafts, quiz you before an exam, or simply study with or alongside you.</p>

<h3>Academic encouragement</h3>
<p>Emotional support matters, too. Seek friends who will wish you luck on your exam, tell you you’ll do great, and congratulate you or commiserate depending on the results. Supportive friends also help you deal with stress and understand your need to stay in when you really need to hit the books. </p>

<h3>Intellectual discussions</h3>
<p>Discussions about ideas are an important way to integrate your social and academic life. Whether you talk about small things you learned in class or tackle big controversial issues, these discussions deepen both your thinking and your friendships.</p>

<p>These types of supports don’t need to come from the same friends – you might study with some and socialize with others – but together they function as an important part of a successful Husky experience.</p>

            
                <h3 class="myuw-heading-page">Resources</h3>
                <ul>
                    
                        <li><a href="https://www.huffingtonpost.com/stacia-pierce/11-secrets-to-choosing-th_b_6038658.html">Choosing the Right Friends</a></li>
                    
                </ul>
            

            
                <h3 class="myuw-heading-page">Related Topic</h3>
                <ul>
                    
                        <li><a href="/husky_experience?article=jobs-come-through-people-you-know">Jobs Come Through People You Know</a></li>
                    
                        <li><a href="/husky_experience?article=you-are-your-network">You Are Your Network</a></li>
                    
                        <li><a href="/husky_experience?article=everything-matters-think-about-it">Everything Matters – Think About It</a></li>
                    
                </ul>
            

        </div>

        <div class="col-md-4">
            <div class="myuw-canvas myuw-article-aside">
                <h3 class="myuw-canvas-title">About Thrive Messages</h3>
                <p>Thrive messages are designed to help UW students succeed wherever they are in their University career. The message address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Make Sense.
                </p>
                <a href="#">Learn more about Thrive and the Husky Experience.</a>
            </div>
        </div>
    </div>

</div>
