{% load static %}

<div class="myuw-article">
    <div class="row">
        <div class="col-md-8">
            <div class="myuw-article-meta">
                <a href="/husky_experience/">Husky Experience</a>: Thrive - Weave it Together
            </div>
            <h2 class="myuw-heading-page">Plan Your Life by Accident</h2>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">

            <figure class="myuw-article-heroimage">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/plan_life_by_accident_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/plan_life_by_accident_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/plan_life_by_accident_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/plan_life_by_accident_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 100vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/plan_life_by_accident_650.jpg' %}"
                         alt="Environmental Science North Cascades Group Field Trip.">
                
                
            </figure>

            <p>Sometimes you intend to have an experience, like an internship in your field of interest. Othertimes, there's "just what happened"–like when your internship doesn't pan out and a friend ropes you into volunteering for Alternative Spring Break, or someone nominates you to be on a panel talking about your undergrad research project. </p>

<p>How do you make the most of these "accidental" experiences? Mine them for information about what does – and does not – engage you. Did the experience bring you joy? Did it sap your energy or fire you up? To get more detailed insights, try the “AEIOU” method. Here’s how Bill Burnett and Dave Evans describe the method in their book, “Designing Your Life”:</p>

<ul>
<li>Activities. What were you actually doing? Was this a structured or unstructured activity? Did you have a specific role to play (team leader) or were you just a participant (at a meeting)?</li>
<li>Environments. Our environment has a profound effect on our emotional state. You feel one way at a football stadium, another in a cathedral. Notice where you were when you were involved in the activity. What kind of place was it, and how did it make you feel?</li>
<li>Interactions. What were you interacting with–people or machines? Was it a new kind of interaction or one you are familiar with? Was it formal or informal?</li>
<li>Objects. Were you interacting with any objects or devices–iPads or smartphones, hockey sticks or sailboats? What were the objects that created or supported your feeling engaged?</li>
<li>Users. Who else was there and what role did they play in making it either a positive or negative experience?</li>
</ul>

<p>When you’re able to identify specifically what makes an experience delightful or dull, you can intentionally choose a next experience, and you’re on your way to designing a fulfilling and happy life.</p>

            
                <h3 class="myuw-heading-page">Resources</h3>
                <ul>
                    
                        <li><a href="https://www.youtube.com/watch?v=SemHh0n19LA">Designing Your Life, TEDXStanford</a></li>
                    
                        <li><a href="http://www.nytimes.com/2010/08/03/opinion/03brooks.html?ref=opinion">The Summoned Self</a></li>
                    
                </ul>
            

            
                <h3 class="myuw-heading-page">Related Topic</h3>
                <ul>
                    
                        <li><a href="/husky_experience?article=jobs-come-through-people-you-know">Jobs Come Through People You Know</a></li>
                    
                        <li><a href="/husky_experience?article=tired-feeling-alone">Tired of Feeling Alone?</a></li>
                    
                        <li><a href="/husky_experience?article=falling-love-class">Falling in Love with a Class</a></li>
                    
                        <li><a href="/husky_experience?article=pitch-your-story">Pitch Your Story</a></li>
                    
                        <li><a href="/husky_experience?article=everything-matters-think-about-it">Everything Matters – Think About It</a></li>
                    
                        <li><a href="/husky_experience?article=got-experience">Got Experience?</a></li>
                    
                </ul>
            

        </div>

        <div class="col-md-4">
            <div class="myuw-canvas myuw-article-aside">
                <h3 class="myuw-canvas-title">About Thrive Messages</h3>
                <p>Thrive messages are designed to help UW students succeed wherever they are in their University career. The message address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Make Sense.
                </p>
                <a href="#">Learn more about Thrive and the Husky Experience.</a>
            </div>
        </div>
    </div>

</div>
