{% load static %}

<div class="myuw-article">
    <div class="row">
        <div class="col-md-8">
            <div class="myuw-article-meta">
                <a href="/husky_experience/">Husky Experience</a>: Thrive - Make Your Way
            </div>
            <h2 class="myuw-heading-page">Pitch Your Story</h2>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">

            <figure class="myuw-article-heroimage">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/pitch_your_story_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/pitch_your_story_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/pitch_your_story_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/pitch_your_story_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 100vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/pitch_your_story_650.jpg' %}"
                         alt="MFA overhead view.">
                
                
                    <p>College of Arts &amp; Sciences</p>
                
            </figure>

            <p>Introducing yourself in social or professional settings can often set up connections for the future. Whether you are attending a formal job fair or mingling at an event, you want to capture a person’s attention and make an impression in a few minutes.</p>

<p>An effective way to connect and to convey your message is a personal elevator pitch. This is a clear, concise, and specific statement that describes you, your interests, and your strengths in less than 30 seconds.</p>
<ul>
<li>Say something about yourself, what you care about, and what you like doing.</li> 

<li>Try creating a few sentences about who you are, what you're seeking, and what you can offer.</li>

<li>Prepare and practice your pitch so it flows naturally. Practice alone and with friends so that you feel comfortable introducing yourself to new people.</li> 

<li>Tweak your pitch often to keep it current and to adapt it to each situation you are in.</li>

<li>Be prepared for the next step; describing your experience, skills and the contributions you hope to make.</li>
</ul>
<p>Ideally your “elevator pitch” will leave someone wanting to know more about you and lead to a longer conversation or additional connections.</p>

            
                <h3 class="myuw-heading-page">Resources</h3>
                <ul>
                    
                        <li><a href="https://www.gcflearnfree.org/jobsearchandnetworking/networking-basics/1/">Job Search and Networking Basics</a></li>
                    
                        <li><a href="https://idealistcareers.org/a-quick-guide-to-writing-your-elevator-pitch-with-examples/">A Quick Guide to Writing Your Elevator Pitch</a></li>
                    
                </ul>
            

            
                <h3 class="myuw-heading-page">Related Topic</h3>
                <ul>
                    
                        <li><a href="/husky_experience?article=jobs-come-through-people-you-know">Jobs Come Through People You Know</a></li>
                    
                        <li><a href="/husky_experience?article=does-your-resume-represent-you">Does Your Résumé Represent You?</a></li>
                    
                        <li><a href="/husky_experience?article=plan-your-life-accident">Plan Your Life by Accident</a></li>
                    
                </ul>
            

        </div>

        <div class="col-md-4">
            <div class="myuw-canvas myuw-article-aside">
                <h3 class="myuw-canvas-title">About Thrive Messages</h3>
                <p>Thrive messages are designed to help UW students succeed wherever they are in their University career. The message address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Make Sense.
                </p>
                <a href="#">Learn more about Thrive and the Husky Experience.</a>
            </div>
        </div>
    </div>

</div>
