{% load static %}

<div class="myuw-article">
    <div class="row">
        <div class="col-md-8">
            <div class="myuw-article-meta">
                <a href="/husky_experience/">Husky Experience</a>: Thrive - Weave it Together
            </div>
            <h2 class="myuw-heading-page">Everything Matters – Think About It</h2>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">

            <figure class="myuw-article-heroimage">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/everything_matters_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/everything_matters_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/everything_matters_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/everything_matters_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 100vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/everything_matters_650.jpg' %}"
                         alt="A shared room in McMahon Hall, just one of 15 undergraduate housing options.">
                
                
                    <p>Doug Plummer</p>
                
            </figure>

            <p>At UW, you have taken classes, met new people, worked or interned or volunteered, made choices about your entertainment or travel. Many educators believe that you haven't really learned from an experience until you've reflected on it. It's reflection that helps you harvest insights from your experiences and make connections among them. There are places at the UW where deep reflection is built into your learning, like the Jackson School Task Force and the <a href="http://huskyleadership.uw.edu/programs/leadership-certificate/" target="_blank">Husky Leadership Certificate</a>, but you can practice reflection anytime.</p>

<p>You can reflect on previous experiences by asking yourself questions like these:</p>
<ul>
<li>What have I done that has been surprising? Scary? Delightful?</li>
<li>When was I the most creative and why?</li>
<li>What experience sparked my curiosity?</li>
<li>What experience has been the most challenging? The most rewarding?</li>
</ul>
<p>You can also incorporate reflection into your everyday life, whether in class or as part of a community:</p>
<ul> 
<li>What are three things I learned today?</li> 
<li>What are two ways I will act on what I learned?</li> 
<li>What is one thing I want to know more about?</li> 
</ul>
<p>Don't let the thought of reflection seem daunting (or time consuming); get in the habit of asking questions and making connections between what you see, hear, read, and experience. This will deepen your learning and guide your next steps.</p>

            

            
                <h3 class="myuw-heading-page">Related Topic</h3>
                <ul>
                    
                        <li><a href="/husky_experience?article=your-friends-your-success">Your Friends, Your Success</a></li>
                    
                        <li><a href="/husky_experience?article=does-your-resume-represent-you">Does Your Résumé Represent You?</a></li>
                    
                        <li><a href="/husky_experience?article=plan-your-life-accident">Plan Your Life by Accident</a></li>
                    
                        <li><a href="/husky_experience?article=fight-decision-fatigue">Fight Decision Fatigue</a></li>
                    
                </ul>
            

        </div>

        <div class="col-md-4">
            <div class="myuw-canvas myuw-article-aside">
                <h3 class="myuw-canvas-title">About Thrive Messages</h3>
                <p>Thrive messages are designed to help UW students succeed wherever they are in their University career. The message address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Make Sense.
                </p>
                <a href="#">Learn more about Thrive and the Husky Experience.</a>
            </div>
        </div>
    </div>

</div>
