{% load static %}

<div class="myuw-article">
    <div class="row">
        <div class="col-md-8">
            <div class="myuw-article-meta">
                <a href="/husky_experience/">Husky Experience</a>: Thrive - Know Yourself
            </div>
            <h2 class="myuw-heading-page">Fight Decision Fatigue</h2>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">

            <figure class="myuw-article-heroimage">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/fight_decision_fatigue_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/fight_decision_fatigue_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/fight_decision_fatigue_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/fight_decision_fatigue_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 100vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/fight_decision_fatigue_650.jpg' %}"
                         alt="None">
                
                
            </figure>

            <p>Sometimes decisions are not life-defining, but seem soul sucking. Study environmental science or work on my essay for history? Go to the accounting club meeting or the leadership lecture? Decisions can be hard and take time but having  some techniques to use makes it easier. Try some of these next time:</p> 
<ul>
<li>Define your choices and seek information</li>
<li>Make a pro/con list or a cost-benefit analysis</li>
<li>Imagine the advice you would give to a friend</li>
<li>Experiment with having the choice made for you and seeing how you feel about it</li>
<li>Need to make a quick decision? Set a timer!</li>
</ul>

            
                <h3 class="myuw-heading-page">Resources</h3>
                <ul>
                    
                        <li><a href="https://www.huffingtonpost.com/entry/3-powerful-decision-making-strategies-of-successful_us_57ed81e6e4b0972364deaed3">3 Powerful Decision-Making Strategies of Successful Leaders</a></li>
                    
                        <li><a href="http://www.wisebread.com/10-ways-to-improve-your-decision-making-skills">10 Ways to Improve Your Decision-Making Skills</a></li>
                    
                </ul>
            

            
                <h3 class="myuw-heading-page">Related Topic</h3>
                <ul>
                    
                        <li><a href="/husky_experience?article=everything-matters-think-about-it">Everything Matters – Think About It</a></li>
                    
                </ul>
            

        </div>

        <div class="col-md-4">
            <div class="myuw-canvas myuw-article-aside">
                <h3 class="myuw-canvas-title">About Thrive Messages</h3>
                <p>Thrive messages are designed to help UW students succeed wherever they are in their University career. The message address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Make Sense.
                </p>
                <a href="#">Learn more about Thrive and the Husky Experience.</a>
            </div>
        </div>
    </div>

</div>
