<ul class="list-unstyled">
    
    <li><a href="/husky_experience?article=wheres-your-focuslearning-or-competing">Where&#39;s Your Focus–Learning or Competing?</a></li>
    
    <li><a href="/husky_experience?article=falling-love-class">Falling in Love with a Class</a></li>
    
    <li><a href="/husky_experience?article=solve-world-problems">Solve World Problems</a></li>
    
    <li><a href="/husky_experience?article=first-impressions-matter">First Impressions Matter</a></li>
    
    <li><a href="/husky_experience?article=got-experience">Got Experience?</a></li>
    
    <li><a href="/husky_experience?article=are-you-your-gpa">Are you your GPA?</a></li>
    
</ul>