{% load static %}

<div class="myuw-article">
    <div class="row">
        <div class="col-md-8">
            <div class="myuw-article-meta">
                <a href="/husky_experience/">Husky Experience</a>: Thrive - Know Yourself
            </div>
            <h2 class="myuw-heading-page">What If the Grade Didn&#39;t Matter?</h2>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">

            <figure class="myuw-article-heroimage">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/what_if_the_grade_didnt_matter_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/what_if_the_grade_didnt_matter_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/what_if_the_grade_didnt_matter_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/what_if_the_grade_didnt_matter_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 100vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/what_if_the_grade_didnt_matter_650.jpg' %}"
                         alt="None">
                
                
            </figure>

            <p>UW is a city of learning with professors whose expertise spans a vast range of topics. Take advantage of this by choosing courses that grab your interest.</p> 

<p>Here are some ways to match your interests to class selection:</p>
<ul>
<li>What news or current events are you drawn to? What big questions keep you up at night? Identify the disciplines (tip: advisers can help!) that will help you explore these ideas.</li>

<li>Think of a faculty member who inspires you, and look at the range of courses he or she teaches. Is there a topic you would not want to miss learning about?</li> 

<li>Browse the <a href="http://www.washington.edu/students/timeschd/  target="_blank">time schedule</a> or search <a href=" https://myplan.uw.edu/" target="_blank">MyPlan</a> for classes that look intriguing.</li> 

<p>It is worth your time to take classes that compel you as they can open up new ideas and opportunities.</p>

            
                <h3 class="myuw-heading-page">Resources</h3>
                <ul>
                    
                        <li><a href="http://campusgrotto.com/taking-classes-outside-your-major.html">Taking Classes Outside your Major</a></li>
                    
                        <li><a href="https://www.teenvogue.com/story/classes-to-take-in-college">Why You Should Step Outside Your Major When Signing Up for Classes</a></li>
                    
                </ul>
            

            
                <h3 class="myuw-heading-page">Related Topic</h3>
                <ul>
                    
                        <li><a href="/husky_experience?article=wheres-your-focuslearning-or-competing">Where&#39;s Your Focus–Learning or Competing?</a></li>
                    
                        <li><a href="/husky_experience?article=falling-love-class">Falling in Love with a Class</a></li>
                    
                        <li><a href="/husky_experience?article=solve-world-problems">Solve World Problems</a></li>
                    
                        <li><a href="/husky_experience?article=what-if-grade-didnt-matter">What If the Grade Didn&#39;t Matter?</a></li>
                    
                </ul>
            

        </div>

        <div class="col-md-4">
            <div class="myuw-canvas myuw-article-aside">
                <h3 class="myuw-canvas-title">About Thrive Messages</h3>
                <p>Thrive messages are designed to help UW students succeed wherever they are in their University career. The message address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Make Sense.
                </p>
                <a href="#">Learn more about Thrive and the Husky Experience.</a>
            </div>
        </div>
    </div>

</div>
