{% load static %}

<div class="myuw-article">
    <div class="row">
        <div class="col-md-8">
            <div class="myuw-article-meta">
                <a href="/husky_experience/">Husky Experience</a>: Thrive - Know the World
            </div>
            <h2 class="myuw-heading-page">First Impressions Matter</h2>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">

            <figure class="myuw-article-heroimage">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/first_impressions_matter_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/first_impressions_matter_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/first_impressions_matter_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/first_impressions_matter_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 100vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/first_impressions_matter_650.jpg' %}"
                         alt="A student on his laptop in Paccar Hall.">
                
                
                    <p>Dennis Wise</p>
                
            </figure>

            <p>Email messages to faculty, mentors, and potential employers should be brief and professional.</p>
<ul>
<li>Include a useful subject line; a title like “meeting” will not be helpful for people who receive dozens of emails per day.</li>
<li>Use a greeting at the beginning: You can’t go wrong with “Hello” or “Dear <their name>.” Default to a formal title (e.g. Mr., Mrs., Dr.) unless you are already on a first-name basis.</li>
<li>AVOID ALL CAPS! Unless you really are intending to shout&#8230;.</li>
<li>Double-check attachments – are they attached? Are they titled appropriately?</li> 
<li>Develop an email signature that includes more information about you, such as a link to your online profile or portfolio.</li>
</ul>
<p>Taking time to present yourself and communicate carefully will help you make good first impressions, both online and in-person.</p>

            
                <h3 class="myuw-heading-page">Resources</h3>
                <ul>
                    
                        <li><a href="https://students.tufts.edu/career-center/i-need/network/professional-email-etiquette">Professional Email Etiquette</a></li>
                    
                </ul>
            

            
                <h3 class="myuw-heading-page">Related Topic</h3>
                <ul>
                    
                        <li><a href="/husky_experience?article=jobs-come-through-people-you-know">Jobs Come Through People You Know</a></li>
                    
                        <li><a href="/husky_experience?article=you-are-your-network">You Are Your Network</a></li>
                    
                </ul>
            

        </div>

        <div class="col-md-4">
            <div class="myuw-canvas myuw-article-aside">
                <h3 class="myuw-canvas-title">About Thrive Messages</h3>
                <p>Thrive messages are designed to help UW students succeed wherever they are in their University career. The message address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Make Sense.
                </p>
                <a href="#">Learn more about Thrive and the Husky Experience.</a>
            </div>
        </div>
    </div>

</div>
