<ul class="list-unstyled">
    
    <li><a href="/husky_experience?article=jobs-come-through-people-you-know">Jobs Come Through People You Know</a></li>
    
    <li><a href="/husky_experience?article=you-are-your-network">You Are Your Network</a></li>
    
    <li><a href="/husky_experience?article=pitch-your-story">Pitch Your Story</a></li>
    
    <li><a href="/husky_experience?article=does-your-resume-represent-you">Does Your Résumé Represent You?</a></li>
    
</ul>