{% load static %}

<div class="myuw-article">
    <div class="row">
        <div class="col-md-8">
            <div class="myuw-article-meta">
                <a href="/husky_experience/">Husky Experience</a>: Thrive - Know the World
            </div>
            <h2 class="myuw-heading-page">Are you your GPA?</h2>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">

            <figure class="myuw-article-heroimage">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/are_you_your_gpa_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/are_you_your_gpa_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/are_you_your_gpa_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/are_you_your_gpa_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 100vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/are_you_your_gpa_650.jpg' %}"
                         alt="Cassady Glass Hastings, undergraduate instructor at the college of education.">
                
                
            </figure>

            <p>Sometimes a high GPA matters a lot, especially if you are aspiring to graduate or professional school. If that's the case, there are many resources on campus to help you improve your skills in reading, writing, problem solving, and time management – <a href="http://webster.uaa.washington.edu/asp/website/get-help/helpful-tips/overview/">Academic Support Programs</a> is a good place to start.</p>

<p>That said, most <a href="http://www.naceweb.org/career-development/trends-and-predictions/job-outlook-2016-attributes-employers-want-to-see-on-new-college-graduates-resumes/">employers care more about your skills</a> and less about your GPA. In what ways are you cultivating your skills in leadership, communication, and teamwork? Here's where you want to think strategically about how you combine academic work and experience outside the classroom. </p>

<p>Getting experience – and even getting good grades – doesn't mean anything unless you can show that you learned. Being able to talk about what you have learned, both inside and outside the classroom, is a key skill. In the end, the whole package – your ability to apply your academic knowledge to real-world problems, your engagement in experience outside the classroom, and a strong professional network – matters more in getting a job than magna cum laude.</p>

            
                <h3 class="myuw-heading-page">Resources</h3>
                <ul>
                    
                        <li><a href="http://www.naceweb.org/career-development/trends-and-predictions/job-outlook-2016-attributes-employers-want-to-see-on-new-college-graduates-resumes/">The Attributes Employers Want to See on New College Graduates’ Resumes</a></li>
                    
                </ul>
            

            
                <h3 class="myuw-heading-page">Related Topic</h3>
                <ul>
                    
                        <li><a href="/husky_experience?article=wheres-your-focuslearning-or-competing">Where&#39;s Your Focus–Learning or Competing?</a></li>
                    
                        <li><a href="/husky_experience?article=do-majors-jobs">Do Majors = Jobs?</a></li>
                    
                        <li><a href="/husky_experience?article=bouncing-back">Bouncing Back</a></li>
                    
                </ul>
            

        </div>

        <div class="col-md-4">
            <div class="myuw-canvas myuw-article-aside">
                <h3 class="myuw-canvas-title">About Thrive Messages</h3>
                <p>Thrive messages are designed to help UW students succeed wherever they are in their University career. The message address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Make Sense.
                </p>
                <a href="#">Learn more about Thrive and the Husky Experience.</a>
            </div>
        </div>
    </div>

</div>
