{% load static %}

<div class="myuw-article">
    <div class="row">
        <div class="col-md-8">
            <div class="myuw-article-meta">
                <a href="/husky_experience/">Husky Experience</a>: Thrive - Know Yourself
            </div>
            <h2 class="myuw-heading-page">No Time to be Healthy?</h2>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">

            <figure class="myuw-article-heroimage">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/no_time_to_be_healthy_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/no_time_to_be_healthy_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/no_time_to_be_healthy_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/no_time_to_be_healthy_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 100vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/no_time_to_be_healthy_650.jpg' %}"
                         alt="A fan literally going crazy during the UW/UCLA game in 2010.">
                
                
                    <p>Tricia Caparas</p>
                
            </figure>

            <p>The college lifestyle doesn’t exactly encourage discipline when it comes to getting a good night’s sleep, exercising, and eating healthy. Especially if you’re crazy busy or feeling stressed, the last thing you probably want to hear is someone reminding you to take care of your health. But you probably know this already: when you prioritize your health, tasks that seem overwhelming suddenly become manageable. And over time, you’re likely to be happier and better able to handle your work and other challenges if you attend to your wellness.</p>

<p>How to do that with limited time? Make time for activities that will restore and nourish your body and brain. Here are some options we found that are great rejuvenators:</p>

<p>Breathe deeply. First thing in the morning, in the shower, on the bus, any time you think of it. Take 5-10 deep breaths that fill your belly and lungs, and exhale slowly. That extra boost of oxygen will clear your mind and help reduce stress.</p>

<p>Meditate. This is more intentional deep breathing, where you find a place to sit, close your eyes, and focus carefully on your inhale and exhale. Acknowledge when thoughts appear, then go back to the breath without any judgment. 15-20 minutes is ideal.</p>

<p>Engage your senses. Prepare a good meal if you can, or at least eat one, slowing down to savor the tastes and textures. Close your eyes and listen fully to your favorite music. Take a walk outside in nature, taking in the smells and temperature of the air. Draw or color. If you're so lucky, play or snuggle with a furry pet.</p>

<p>Move. Do anything to get your blood pumping for at least a minute, multiple times a day. 25 jumping jacks. Wild dancing to your favorite tunes. Skipping across the quad--getting outside provides an extra boost. This kind of movement can interrupt the stress response. And it will probably make you want to move more often, for longer.</p>

<p>Feel gratitude. When you spend time thinking about someone or something you appreciate, you release positive brain chemicals. New brain science says that you’re a tiny bit healthier whenever you conjure a positive emotional thought. Make it a goal every day to conjure more positive thoughts than negative. </p>

<p>Say no. To whatever you know will cause you to overextend yourself. Or whatever doesn’t feel right for you.</p>

<p>Say yes. To goofing around and laughing hard. To spending time talking with others--in person or on the phone. Really restorative activity gets you away from the screen.</p>

<p>Sleep. Yeah, we know you’ve heard this one before, but here it is again because it’s so important. Your body needs sleep to function at its best, physically, mentally, emotionally. Can’t get 8 hours of sleep? Nap. Research says 25 minutes is good, 60-90 minutes is better. </p>

<p>Take care of your health, and other things will look a lot more manageable.</p>

            
                <h3 class="myuw-heading-page">Resources</h3>
                <ul>
                    
                        <li><a href="https://fyp.washington.edu/healthyhuskies/">Healthy Huskies</a></li>
                    
                </ul>
            

            
                <h3 class="myuw-heading-page">Related Topic</h3>
                <ul>
                    
                        <li><a href="/husky_experience?article=bouncing-back">Bouncing Back</a></li>
                    
                </ul>
            

        </div>

        <div class="col-md-4">
            <div class="myuw-canvas myuw-article-aside">
                <h3 class="myuw-canvas-title">About Thrive Messages</h3>
                <p>Thrive messages are designed to help UW students succeed wherever they are in their University career. The message address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Make Sense.
                </p>
                <a href="#">Learn more about Thrive and the Husky Experience.</a>
            </div>
        </div>
    </div>

</div>
