{% load static %}

<div class="myuw-article">
    <div class="row">
        <div class="col-md-8">
            <div class="myuw-article-meta">
                <a href="/husky_experience/">Husky Experience</a>: Thrive - Know the World
            </div>
            <h2 class="myuw-heading-page">Falling in Love with a Class</h2>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">

            <figure class="myuw-article-heroimage">
                
                    <img class="myuw-card-image-full"
                         srcset="{% static 'hx_toolkit_output/images/falling_love_with_class_480.jpg' %} 480w,
                             {% static 'hx_toolkit_output/images/falling_love_with_class_650.jpg' %} 650w,
                             {% static 'hx_toolkit_output/images/falling_love_with_class_780.jpg' %} 780w,
                             {% static 'hx_toolkit_output/images/falling_love_with_class_1000.jpg' %} 1000w"
                         sizes="(max-width: 767px) 100vw,
                            650px"
                         src="{% static 'hx_toolkit_output/images/falling_love_with_class_650.jpg' %}"
                         alt="Dance instructor Steven Sofia teaches UW students how to tap dance at the Meany Hall dance studio.">
                
                
            </figure>

            <p>No matter your major (yes, some courses you just must take), choosing your classess continues to be a way to explore new ideas, challenge yourself, and be immersed in different worlds. You can make those NWs and VLPAs work for you! Here are some ideas: </p>

<ul>
<li>Check out the current courses being taught faculty who have won <a href=" http://www.washington.edu/teaching/awards/awards-recipients">Distinguished Teaching Awards</a>.</li>
<li>Think back on your favorite class or subject – what courses will give you the opportunity to dive deeper?</li>
<li>Is your favorite faculty teaching something new? Email them and ask!</li>
<li>Advisers have <a href="https://www.washington.edu/uaa/advising/academic-planning/choosing-courses/courses-recommended-by-advisers">suggestions for great courses</a> in their departments; searching websites and blogs can often unearth some gems.</li>
<li>Ask your friends about their favorite classes.</li>
</ul>

            
                <h3 class="myuw-heading-page">Resources</h3>
                <ul>
                    
                        <li><a href="https://www.washington.edu/uaa/advising/academic-planning/choosing-courses/overview/">What Courses Should I Take?</a></li>
                    
                </ul>
            

            
                <h3 class="myuw-heading-page">Related Topic</h3>
                <ul>
                    
                        <li><a href="/husky_experience?article=solve-world-problems">Solve World Problems</a></li>
                    
                        <li><a href="/husky_experience?article=do-majors-jobs">Do Majors = Jobs?</a></li>
                    
                        <li><a href="/husky_experience?article=plan-your-life-accident">Plan Your Life by Accident</a></li>
                    
                        <li><a href="/husky_experience?article=what-if-grade-didnt-matter">What If the Grade Didn&#39;t Matter?</a></li>
                    
                </ul>
            

        </div>

        <div class="col-md-4">
            <div class="myuw-canvas myuw-article-aside">
                <h3 class="myuw-canvas-title">About Thrive Messages</h3>
                <p>Thrive messages are designed to help UW students succeed wherever they are in their University career. The message address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Make Sense.
                </p>
                <a href="#">Learn more about Thrive and the Husky Experience.</a>
            </div>
        </div>
    </div>

</div>
