<ul class="list-unstyled">
    
    <li><a href="/husky_experience?article=your-friends-your-success">Your Friends, Your Success</a></li>
    
    <li><a href="/husky_experience?article=tired-feeling-alone">Tired of Feeling Alone?</a></li>
    
    <li><a href="/husky_experience?article=no-time-be-healthy">No Time to be Healthy?</a></li>
    
    <li><a href="/husky_experience?article=do-majors-jobs">Do Majors = Jobs?</a></li>
    
    <li><a href="/husky_experience?article=bouncing-back">Bouncing Back</a></li>
    
    <li><a href="/husky_experience?article=what-if-grade-didnt-matter">What If the Grade Didn&#39;t Matter?</a></li>
    
    <li><a href="/husky_experience?article=fight-decision-fatigue">Fight Decision Fatigue</a></li>
    
</ul>